Mesa (master): st/mesa: replace 'usage' with 'bindings' to be consistent

Brian Paul brianp at kemper.freedesktop.org
Fri Apr 23 19:18:09 UTC 2010


Module: Mesa
Branch: master
Commit: eb2bd2158ed8c1983ef427ea792dc159a2144c08
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=eb2bd2158ed8c1983ef427ea792dc159a2144c08

Author: Brian Paul <brianp at vmware.com>
Date:   Fri Apr 23 13:05:13 2010 -0600

st/mesa: replace 'usage' with 'bindings' to be consistent

Plus, update comments and formatting.

---

 src/mesa/state_tracker/st_cb_fbo.c |   16 ++++++----------
 1 files changed, 6 insertions(+), 10 deletions(-)

diff --git a/src/mesa/state_tracker/st_cb_fbo.c b/src/mesa/state_tracker/st_cb_fbo.c
index 1ba1fe1..e59ece7 100644
--- a/src/mesa/state_tracker/st_cb_fbo.c
+++ b/src/mesa/state_tracker/st_cb_fbo.c
@@ -422,23 +422,19 @@ st_finish_render_texture(GLcontext *ctx,
 
 
 /**
  * Validate a renderbuffer attachment for a particular usage.
  */
-
 static GLboolean
 st_validate_attachment(struct pipe_screen *screen,
 		       const struct gl_renderbuffer_attachment *att,
-		       GLuint usage)
+		       unsigned bindings)
 {
-   const struct st_texture_object *stObj =
-      st_texture_object(att->Texture);
+   const struct st_texture_object *stObj = st_texture_object(att->Texture);
 
-   /**
-    * Only validate texture attachments for now, since
+   /* Only validate texture attachments for now, since
     * st_renderbuffer_alloc_storage makes sure that
     * the format is supported.
     */
-
    if (att->Type != GL_TEXTURE)
       return GL_TRUE;
 
@@ -446,10 +442,10 @@ st_validate_attachment(struct pipe_screen *screen,
       return GL_FALSE;
 
    return screen->is_format_supported(screen, stObj->pt->format,
-				      PIPE_TEXTURE_2D,
-				      usage, 0);
+				      PIPE_TEXTURE_2D, bindings, 0);
 }
 
+
 /**
  * Check that the framebuffer configuration is valid in terms of what
  * the driver can support.
@@ -422,23 +422,19 @@ st_finish_render_texture(GLcontext *ctx,
 
 /**
- * Validate a renderbuffer attachment for a particular usage.
+ * Validate a renderbuffer attachment for a particular set of bindings.
  */




More information about the mesa-commit mailing list